@@ -1,7 +1,9 @@
 package Dist::Zilla::Plugin::InsertCodeResult;
 
-our $DATE = '2019-02-04'; # DATE
-our $VERSION = '0.051'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-02-21'; # DATE
+our $DIST = 'Dist-Zilla-Plugin-InsertCodeResult'; # DIST
+our $VERSION = '0.052'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,9 +32,14 @@ sub munge_files {
 sub munge_file {
     my ($self, $file) = @_;
     my $content = $file->content;
-    if ($content =~ s{^#\s*CODE:\s*(.*)\s*$}{$self->_code_result($1)."\n"}egm) {
-        $self->log(["inserting result of code '%s' in %s", $1, $file->name]);
-        $self->log_debug(["result of code: '%s'", $content]);
+    if ($content =~ s{
+                         ^\#\s*CODE:\s*(.*)\s*$ |
+                         ^\#\s*BEGIN_CODE\s*\R((?:.|\R)*?)^\#\s*END_CODE\s*(?:\R|\z)
+                 }{
+                     $self->_code_result($1 // $2)."\n"
+                 }egmx) {
+        $self->log(["inserting result of code '%s' in %s", $1 // $2, $file->name]);
+        $self->log_debug(["content of %s after code result insertion: '%s'", $file->name, $content]);
         $file->content($content);
     }
 }
@@ -73,7 +80,7 @@ Dist::Zilla::Plugin::InsertCodeResult - Insert the result of Perl code into your
 
 =head1 VERSION
 
-This document describes version 0.051 of Dist::Zilla::Plugin::InsertCodeResult (from Perl distribution Dist-Zilla-Plugin-InsertCodeResult), released on 2019-02-04.
+This document describes version 0.052 of Dist::Zilla::Plugin::InsertCodeResult (from Perl distribution Dist-Zilla-Plugin-InsertCodeResult), released on 2020-02-21.
 
 =head1 SYNOPSIS
 
@@ -86,13 +93,24 @@ In your POD:
 
  # CODE: require MyLib; MyLib::gen_stuff("some", "param");
 
+or for multiline code:
+
+ # BEGIN_CODE
+ require MyLib;
+ MyLib::gen_stuff("some", "param");
+ ...
+ # END_CODE
+
 =head1 DESCRIPTION
 
-This module finds C<# CODE: ...> directives in your POD, evals the specified
-Perl code, and insert the result into your POD as a verbatim paragraph (unless
-you set C<make_verbatim> to 0, in which case output will be inserted as-is). If
-result is a simple scalar, it is printed as is. If it is undef or a reference,
-it will be dumped using L<Data::Dump>. If eval fails, build will be aborted.
+This module finds C<# CODE: ...> or C<# BEGIN_CODE> and C<# END CODE> directives
+in your POD, evals the specified Perl code, and insert the result into your POD
+as a verbatim paragraph (unless you set C<make_verbatim> to 0, in which case
+output will be inserted as-is). If result is a simple scalar, it is printed as
+is. If it is undef or a reference, it will be dumped using L<Data::Dump>. If
+eval fails, build will be aborted.
+
+The directives must be at the first column of the line.
 
 =for Pod::Coverage .+
 
@@ -114,6 +132,8 @@ feature.
 
 =head1 SEE ALSO
 
+L<Dist::Zilla::Plugin::InsertCodeOutput>
+
 L<Dist::Zilla::Plugin::InsertExample>
 
 =head1 AUTHOR
@@ -122,7 +142,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
